package com.junmp.jyzb.controller;

import com.junmp.jyzb.domain.Policeman;
import com.junmp.jyzb.service.PoliceFingerService;
import com.junmp.jyzb.service.PolicemanService;
import com.junmp.jyzb.utils.ResponseResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@Slf4j
@RequestMapping("/Police")
@Api(tags = "警员基础信息模块")
public class PoliceController {

    @Resource
    public PolicemanService policemanService;

    @Resource
    private PoliceFingerService fingerService;

    @PostMapping("/GetAllPolice")
    @ApiOperation("查询警员列表")
    public ResponseResult getAllPoliceman(@RequestBody Map<String, Object> orgId){
        //获取该组织机构下所有警员的id
        List<Map<String, Object>> allPoliceman=new ArrayList<>();
        List<String> allPoliceId =policemanService.getAllPoliceId(orgId);
        for (String policeId :allPoliceId){
            Map<String, Object> policeMsg = policemanService.getOnePolice(policeId);
            List<Map<String, Object>> fingerprints= fingerService.getFingersByUserId(policeId);
            policeMsg.put("fingerMsg",fingerprints);
            allPoliceman.add(policeMsg);
        }

        return new ResponseResult(10000,"操作成功",allPoliceman);
    }

    @PostMapping("/GetOnePolice")
    @ApiOperation("查询单个警员信息")
    public ResponseResult getOnePolice(@RequestBody Map<String, Object> msg) {
        String userId = msg.get("policeId").toString();
        Map<String, Object> policeMsg = policemanService.getOnePolice(userId);

        List<Map<String, Object>> fingerprints = fingerService.getFingersByUserId(userId);
        policeMsg.put("fingerMsg",fingerprints);

        return new ResponseResult(10000,"操作成功",policeMsg);
    }

    @PostMapping("/AddPoliceman")
    @ApiOperation("添加警员信息")
    public ResponseResult addPoliceman(@RequestBody Map<String,Object> msg) {
        policemanService.addPoliceman(msg);
        return new ResponseResult(10000,"操作成功");
    }

    @PostMapping("/DeletePolice")
    @ApiOperation("删除警员信息")
    public ResponseResult deletePolice(@RequestBody Map<String,Object> msg) {
        policemanService.deletePolice(msg);
        return new ResponseResult(10000,"操作成功");
    }

    @PostMapping("/UpdatePolice")
    @ApiOperation("修改警员信息")
    public ResponseResult updatePolice(@RequestBody Map<String,Object> msg) {
        policemanService.updatePolice(msg);
        return new ResponseResult(10000,"操作成功");
    }

    @PostMapping("/DeletePoliceFinger")
    @ApiOperation("删除警员指纹信息")
    public ResponseResult deletePoliceFinger(@RequestBody Map<String,Object> msg) {
        policemanService.deleteFinger(msg);
        return new ResponseResult(10000,"操作成功");
    }
}
